@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 
-from django.http import HttpResponseRedirect
-from django.template import RequestContext
-from django.shortcuts import render_to_response
 from django.contrib import admin, messages
 from django.db.models import Q
+from django.http import HttpResponseRedirect
+from django.shortcuts import render_to_response
+from django.template import RequestContext
 from django.utils.http import urlencode, urlunquote
-
+from django.utils.translation import ugettext as _
 from django_stachoutils.options import paginate
 from django_stachoutils.views.actions import regroup_actions
 
@@ -23,29 +23,33 @@ def generic_change_response(request, url_continue, url_add_another, url_default)
         return HttpResponseRedirect(url_default)
 
 
-def liste_generique(request, queryset, columns, template, Model, ClassAdmin=None,
-                    actions=[], filters=(), links=(), search=(), default_order=None,
-                    paginate_by_default=100, paginates_by=[], qset_modifier=None,
-                    qset_modifier_args=[], extra_params={}):
+def generic_list(request, queryset, columns, template, Model, ClassAdmin=None,
+                 actions=[], filters=(), links=(), search=(), default_order=None,
+                 paginate_by_default=100, paginates_by=[], qset_modifier=None,
+                 qset_modifier_args=[], extra_params={}):
     """
      actions_par_groupe = [
-        ('groupeA', [('action_1', 'libellé de l'action 1'), ('action_3', 'libellé de l'action 3')]),
+        ('groupeA', [('action_1', 'libellé de l'action 1'),
+                     ('action_3', 'libellé de l'action 3')]),
         ('groupeB', [('action_2', 'libellé de l'action 2')]),
      ]
     """
     list_id = Model._meta.verbose_name
-    user_settings = request.session.get('preferences', {})
 
     # Actions.
     actions = regroup_actions(actions)
     actions_par_groupe = []
     if ClassAdmin and actions:
         adm = ClassAdmin(Model, admin.site)
-        admin_actions = adm.get_actions(request)  # {'invalider': (<unbound method ProgrammeAdmin.invalider>, 'invalider', u'Invalider en...'), ...}
+        # {'invalider': (<unbound method ProgrammeAdmin.invalider>,
+        #  'invalider', u'Invalider en...'), ...}
+        admin_actions = adm.get_actions(request)
         for group, actions_in_group in actions:
-            actions_dispos = [(callable(action) and action.func_name or action,
-                              action in admin_actions and admin_actions[action][2] or action.short_description)
-                              for action in actions_in_group if action in admin_actions or callable(action)]
+            actions_dispos = [
+                (callable(action) and action.func_name or action,
+                 action in admin_actions and admin_actions[action][2] or action.short_description)
+                for action in actions_in_group if action in admin_actions or callable(action)
+            ]
             if actions_dispos:
                 actions_par_groupe.append((group, actions_dispos))
 
@@ -99,8 +103,7 @@ def liste_generique(request, queryset, columns, template, Model, ClassAdmin=None
     page = paginate(request, queryset, paginate_by_default)
 
     # Filters.
-    closed_filters = user_settings.get('%s_closed_filters' % list_id, [])
-    filters = [get_filter(Model, current_filters, closed_filters, f) for f in filters]
+    filters = [get_filter(Model, current_filters, f) for f in filters]
 
     # Exec action.
     if request.method == 'POST':
@@ -135,7 +138,7 @@ def liste_generique(request, queryset, columns, template, Model, ClassAdmin=None
         'paginates_by': request.GET.get('paginates_by', paginates_by),
         'columns': columns,
         'actions': actions_par_groupe,
-        'filtres': filters,  # renommer en filters.
+        'filters': filters,
         'links': links,
         'search': [s[0] for s in search],
         'get_params': dict(request.GET.items()),
@@ -162,7 +165,7 @@ def has_column_perm(user, column):
     return True
 
 
-def get_filter(model, current_filters, closed_filters, filtr):
+def get_filter(model, current_filters, filtr):
     p = {
         'choices': None,
         'empty_choice': False,
@@ -174,7 +177,8 @@ def get_filter(model, current_filters, closed_filters, filtr):
         p['attr'] = filtr[0]
         p.update(filtr[1])
 
-    choices, empty_choice, attr, filter_test = p['choices'], p['empty_choice'], p['attr'], p['filter_test']
+    choices, empty_choice = p['choices'], p['empty_choice']
+    attr, filter_test = p['attr'], p['filter_test']
 
     filter_string = attr
     attrs = attr.split('__')
@@ -200,14 +204,21 @@ def get_filter(model, current_filters, closed_filters, filtr):
         )
         F = FilterSimple
 
-    choices = [(lambda f=F(o, attr, filter_string, filter_test, current_filters): (f.url, f.label, f.is_selected))() for o in choices]
-    choices.insert(0, (lambda f=FilterAll(attr, filter_string, filter_test, current_filters): (f.url, f.label, f.is_selected))())
+    choices = [
+        (lambda f=F(o, attr, filter_string, filter_test, current_filters): (
+            f.url, f.label, f.is_selected))()
+        for o in choices
+    ]
+    choices.insert(0, (lambda f=FilterAll(attr, filter_string, filter_test, current_filters): (
+        f.url, f.label, f.is_selected))())
     if empty_choice:
-        choices.append((lambda f=FilterNone(model, attr, filter_string, current_filters): (f.url, f.label, f.is_selected))())
-    return (name, (name in closed_filters), choices)
+        choices.append((lambda f=FilterNone(model, attr, filter_string, current_filters): (
+            f.url, f.label, f.is_selected))())
+    return (name, choices)
 
 
-def get_current_filter(request, declared_filters, model, ignore=['page', 'paginates_by', 'q', ORDER_BY_ATTR, ORDER_TYPE_ATTR]):
+def get_current_filter(request, declared_filters, model,
+                       ignore=['page', 'paginates_by', 'q', ORDER_BY_ATTR, ORDER_TYPE_ATTR]):
     flat_declared_filters = [(hasattr(f, 'encode') and f or f[0]) for f in declared_filters]
     out = {}
     for k, v in request.GET.items():
@@ -314,7 +325,7 @@ class FilterAll(Filter):
 
     def __init__(self, attr, filter_string, test, current_filters):
         super(FilterAll, self).__init__(None, attr, filter_string, test, current_filters)
-        self.label = u'Tout'
+        self.label = _("All")
         self.value = None
 
     def _get_is_selected(self):
